@@ -4,7 +4,7 @@ import json
 import numpy
 from nn_trainer.trainers.abstract_nn_trainer import AbstractNnTrainer
 
-
+from logging import Logger
 from nn_trainer.metrics import *
 from nn_trainer.callbacks import *
 from nn_trainer.trainers import *
@@ -16,6 +16,11 @@ import torch.utils.data as td
 
 from typing import Dict
 
+def make_path(output_path):
+    if not os.path.isdir(output_path):
+        os.makedirs(output_path)
+    return output_path
+
 class VanillaGanNnTrainer(AbstractNnTrainer):
     """
     Basic implementation of a generative adversarial network trainer using custom loss metrics
@@ -26,7 +31,6 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
     """
     def __init__(
         self,
-        args,
         generator_neural_network: torch.nn.Module, 
         discriminator_neural_network: torch.nn.Module, 
         generator_optimizer_fn: Any = torch.optim.Adam,
@@ -38,12 +42,14 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
         dtype: Any = torch.float32,
         verbose: bool = False,
         patience: int = 0,
-        logger: Any = None,
+        max_epoch_count:int = 200,
+        batch_size:int = 32,
+        output_dir:str = os.path.join(os.getcwd(), "output"),
+        logger:Logger = None
         ):
         """[summary]
 
         Args:
-            args (Any): Command line args
             generator_neural_network (torch.nn.Module): [description]
             discriminator_neural_network (torch.nn.Module): [description]
             generator_optimizer_fn (Any, optional): [description]. Defaults to torch.optim.Adam.
@@ -55,10 +61,9 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
             dtype (Any, optional): [description]. Defaults to torch.float32.
             verbose (bool, optional): [description]. Defaults to False.
             patience (int, optional): [description]. Defaults to 0.
-            logger (Any, optional): [description]. Defaults to None.
+            logger (Logger, optional): [description]. Defaults to None.
         """
         super().__init__(
-            args,
             generator_neural_network, 
             generator_optimizer_fn,
             generator_optimizer_params,
@@ -67,6 +72,9 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
             dtype,
             verbose,
             patience,
+            max_epoch_count,
+            batch_size,
+            output_dir,
             logger)
         self._net_d = discriminator_neural_network.type(dtype)
         self._net_d.to(self._device)
@@ -111,7 +119,7 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
         
         self._eval_names = ['validation']
 
-        with open(os.path.join(self._model_directory_path, 'training_config.json'), 'w') as f: json.dump(self._args, f, indent=4)
+        #with open(os.path.join(self._model_directory_path, 'training_config.json'), 'w') as f: json.dump(self._args, f, indent=4)
 
         self._stop_training = False
 
